# What's Changed

1. 修复: 通过 provider 指令设置提供商，重启后失效
2. 新增: WebChat 支持直接选择提供商和模型
3. 优化: WebUI 视觉效果、WebChat 视觉效果
4. 优化: WebUI 测试提供商功能
5. 优化: 修复潜在的 README XSS 注入问题
6. 修复: WechatPadPro 授权码提取逻辑以适配上游新版本，并提高安全性
7. 修复: Gemini 下，多轮工具调用时可能报错的问题
8. 其他修复与优化